# Generated by Django 3.2.7 on 2022-04-14 07:43

from django.db import migrations, models
import django_sso.gate.models


class Migration(migrations.Migration):

    dependencies = [
        ('gate', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='service',
            name='token',
            field=models.CharField(default=django_sso.gate.models.service_token_generator, max_length=128, unique=True, verbose_name='Token'),
        ),
    ]
