# Generated by Django 3.2.7 on 2022-04-14 11:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('gate', '0002_alter_service_token'),
    ]

    operations = [
        migrations.AddField(
            model_name='authenticationrequest',
            name='next_url',
            field=models.CharField(default=None, help_text='To go after success auth', max_length=512, verbose_name='Next url'),
            preserve_default=False,
        ),
    ]
