# Generated by Django 3.2.7 on 2022-04-21 04:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('gate', '0003_authenticationrequest_next_url'),
    ]

    operations = [
        migrations.AddField(
            model_name='authenticationrequest',
            name='authenticated',
            field=models.BooleanField(default=False, verbose_name='Request has been activated'),
        ),
    ]
